@@ -3,14 +3,13 @@ use warnings;
 
 package Test::File::ShareDir;
 BEGIN {
-  $Test::File::ShareDir::VERSION = '0.1.1';
+  $Test::File::ShareDir::VERSION = '0.1.2';
 }
 
 # ABSTRACT: Create a Fake ShareDir for your modules for testing.
 
 
 
-
 use File::ShareDir 1.00 qw();
 
 sub import {
@@ -20,8 +19,12 @@ sub import {
 
   my $object = Test::File::ShareDir::TempDirObject->new( \%input_config );
 
-  for my $module ( $object->_module_names ){
-      $object->_install_module( $module );
+  for my $module ( $object->_module_names ) {
+    $object->_install_module($module);
+  }
+
+  for my $dist ( $object->_dist_names ) {
+    $object->_install_dist($dist);
   }
 
   unshift @INC, $object->_tempdir->stringify;
@@ -40,7 +43,7 @@ Test::File::ShareDir - Create a Fake ShareDir for your modules for testing.
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
@@ -52,18 +55,22 @@ version 0.1.1
         -root => "$FindBin::Bin/../",
         -share => {
             -module => { 'My::Module' => 'share/MyModule' }
+            -dist   => { 'My-Dist'    => 'share/somefolder' }
         };
 
     use My::Module;
 
-    use File::ShareDir qw( module_dir );
+    use File::ShareDir qw( module_dir dist_dir );
 
     module_dir( 'My::Module' ) # dir with files from $dist/share/MyModule
 
+    dist_dir( 'My-Dist' ) # dir with files from $dist/share/somefolder
+
 =head1 DESCRIPTION
 
-At present, this module only has support for creating test-worth 'module' sharedirs, and then
-these are 'new' style sharedirs and are NOT compatible with old File::ShareDirs.
+This module only has support for creating 'new' style sharedirs and are NOT compatible with old File::ShareDirs.
+
+For this reason, unless you have File::ShareDir 1.00 or later installed, this module will not be usable by you.
 
 =head1 AUTHOR
 
